=====
Text Frequency
=====

Description:
-----
Count letters, letter pairs and words in a text file. Can handle non-Latin scripts.

Installation:
-----
- pip or easy_install 'textfreq'

Usage:
-----
In Shell/Command-prompt: ``textfreq <INPUT.txt> <OUTPUT.txt> <optional commands: -w (words), -p (pairs), -l (letters)>``

Version History:
-----
***V0.001***
- Added words, pairs and letter counts
